Package: rgsepd
Type: Package
Title: Gene Set Enrichment / Projection Displays
Version: 1.42.0
Date: 2022-03-22
Author: Karl Stamm
Maintainer: Karl Stamm <karl.stamm@gmail.com>
Description: R/GSEPD is a bioinformatics package for R to help
        disambiguate transcriptome samples (a matrix of RNA-Seq counts
        at transcript IDs) by automating differential expression (with
        DESeq2), then gene set enrichment (with GOSeq), and finally a
        N-dimensional projection to quantify in which ways each sample
        is like either treatment group. 
Depends: R (>= 4.2.0), DESeq2, goseq (>= 1.28)
Imports: gplots, biomaRt, org.Hs.eg.db, GO.db, SummarizedExperiment,
        AnnotationDbi
Suggests: boot, tools, BiocGenerics, knitr, xtable
License: GPL-3
biocViews: ImmunoOncology, Software, DifferentialExpression,
        GeneSetEnrichment, RNASeq
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/rgsepd
git_branch: RELEASE_3_22
git_last_commit: c033fd6
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 06:06:09 UTC; biocbuild
